@@ -31,7 +31,15 @@ from .utils import (
 from .downloaders import choose_downloader
 
 
-def retrieve(url, known_hash, fname=None, path=None, processor=None, downloader=None):
+def retrieve(
+    url,
+    known_hash,
+    fname=None,
+    path=None,
+    processor=None,
+    downloader=None,
+    progressbar=False,
+):
     """
     Download and cache a single file locally.
 
@@ -97,6 +105,11 @@ def retrieve(url, known_hash, fname=None, path=None, processor=None, downloader=
         If not None, then a function (or callable object) that will be called
         to download a given URL to a provided local file name. See
         :ref:`downloaders` for details.
+    progressbar : bool or an arbitrary progress bar object
+        If True, will print a progress bar of the download to standard error
+        (stderr). Requires `tqdm <https://github.com/tqdm/tqdm>`__ to be
+        installed. Alternatively, an arbitrary progress bar object can be
+        passed. See :ref:`custom-progressbar` for details.
 
     Returns
     -------
@@ -113,7 +126,7 @@ def retrieve(url, known_hash, fname=None, path=None, processor=None, downloader=
     >>> from pooch import __version__, check_version, retrieve
     >>> # Make a URL for the version of pooch we have installed
     >>> url = "https://github.com/fatiando/pooch/raw/{}/data/tiny-data.txt"
-    >>> url = url.format(check_version(__version__))
+    >>> url = url.format(check_version(__version__, fallback="main"))
     >>> # Download the file and save it locally. Will check the MD5 checksum of
     >>> # the downloaded file against the given value to make sure it's the
     >>> # right file. You can use other hashes by specifying different
@@ -141,7 +154,7 @@ def retrieve(url, known_hash, fname=None, path=None, processor=None, downloader=
     >>> # URLs to a gzip compressed version of the data file.
     >>> url = ("https://github.com/fatiando/pooch/raw/{}/"
     ...        + "pooch/tests/data/tiny-data.txt.gz")
-    >>> url = url.format(check_version(__version__))
+    >>> url = url.format(check_version(__version__, fallback="main"))
     >>> # By default, you would have to decompress the file yourself
     >>> fname = retrieve(
     ...     url,
@@ -173,7 +186,7 @@ def retrieve(url, known_hash, fname=None, path=None, processor=None, downloader=
     >>> # URLs to a zip archive with a single data file.
     >>> url = ("https://github.com/fatiando/pooch/raw/{}/"
     ...        + "pooch/tests/data/tiny-data.zip")
-    >>> url = url.format(check_version(__version__))
+    >>> url = url.format(check_version(__version__, fallback="main"))
     >>> # By default, you would get the path to the archive
     >>> fname = retrieve(
     ...     url,
@@ -222,7 +235,7 @@ def retrieve(url, known_hash, fname=None, path=None, processor=None, downloader=
         )
 
         if downloader is None:
-            downloader = choose_downloader(url)
+            downloader = choose_downloader(url, progressbar=progressbar)
 
         stream_download(url, full_path, known_hash, downloader, pooch=None)
 
@@ -250,6 +263,7 @@ def create(
     registry=None,
     urls=None,
     retry_if_failed=0,
+    allow_updates=True,
 ):
     """
     Create a :class:`~pooch.Pooch` with sensible defaults to fetch data files.
@@ -314,6 +328,13 @@ def create(
         attempted once (``retry_if_failed=0``). Initially, will wait for 1s
         between retries and then increase the wait time by 1s with each retry
         until a maximum of 10s.
+    allow_updates : bool or str
+        Whether existing files in local storage that have a hash mismatch with
+        the registry are allowed to update from the remote URL. If a string is
+        passed, we will assume it's the name of an environment variable that
+        will be checked for the true/false value. If ``False``, any mismatch
+        with hashes in the registry will result in an error. Defaults to
+        ``True``.
 
     Returns
     -------
@@ -401,12 +422,15 @@ def create(
     # to import at the same time (which would try to create the folder several
     # times at once).
     path = cache_location(path, env, version)
+    if isinstance(allow_updates, str):
+        allow_updates = os.environ.get(allow_updates, "true").lower() != "false"
     pup = Pooch(
         path=path,
         base_url=base_url,
         registry=registry,
         urls=urls,
         retry_if_failed=retry_if_failed,
+        allow_updates=allow_updates,
     )
     return pup
 
@@ -444,10 +468,23 @@ class Pooch:
         attempted once (``retry_if_failed=0``). Initially, will wait for 1s
         between retries and then increase the wait time by 1s with each retry
         until a maximum of 10s.
+    allow_updates : bool
+        Whether existing files in local storage that have a hash mismatch with
+        the registry are allowed to update from the remote URL. If ``False``,
+        any mismatch with hashes in the registry will result in an error.
+        Defaults to ``True``.
 
     """
 
-    def __init__(self, path, base_url, registry=None, urls=None, retry_if_failed=0):
+    def __init__(
+        self,
+        path,
+        base_url,
+        registry=None,
+        urls=None,
+        retry_if_failed=0,
+        allow_updates=True,
+    ):
         self.path = path
         self.base_url = base_url
         if registry is None:
@@ -457,6 +494,7 @@ class Pooch:
             urls = dict()
         self.urls = dict(urls)
         self.retry_if_failed = retry_if_failed
+        self.allow_updates = allow_updates
 
     @property
     def abspath(self):
@@ -468,7 +506,7 @@ class Pooch:
         "List of file names on the registry"
         return list(self.registry)
 
-    def fetch(self, fname, processor=None, downloader=None):
+    def fetch(self, fname, processor=None, downloader=None, progressbar=False):
         """
         Get the absolute path to a file in the local storage.
 
@@ -506,6 +544,11 @@ class Pooch:
             If not None, then a function (or callable object) that will be
             called to download a given URL to a provided local file name. See
             :ref:`downloaders` for details.
+        progressbar : bool or an arbitrary progress bar object
+            If True, will print a progress bar of the download to standard
+            error (stderr). Requires `tqdm <https://github.com/tqdm/tqdm>`__ to
+            be installed. Alternatively, an arbitrary progress bar object can
+            be passed. See :ref:`custom-progressbar` for details.
 
         Returns
         -------
@@ -524,6 +567,11 @@ class Pooch:
         known_hash = self.registry[fname]
         action, verb = download_action(full_path, known_hash)
 
+        if action == "update" and not self.allow_updates:
+            raise ValueError(
+                f"{fname} needs to update {full_path} but updates are disallowed."
+            )
+
         if action in ("download", "update"):
             get_logger().info(
                 "%s file '%s' from '%s' to '%s'.",
@@ -534,7 +582,7 @@ class Pooch:
             )
 
             if downloader is None:
-                downloader = choose_downloader(url)
+                downloader = choose_downloader(url, progressbar=progressbar)
 
             stream_download(
                 url,
